@@ -1,9 +1,14 @@
 require 'bundler/setup'
-require 'minitest/autorun'
 
-require 'delayer/deferred'
 require 'securerandom'
 require 'set'
 require 'timeout'
-
 require_relative 'testutils'
+
+require 'simplecov'
+SimpleCov.start do
+  add_filter "/test/"
+end
+
+require 'delayer/deferred'
+require 'minitest/autorun'
